@@ -7,10 +7,10 @@ from typing import Dict, List, Tuple, Union
 
 import numpy as np
 import pandas as pd
+from humanfriendly import format_timespan
+
 from fseval.pipeline.estimator import Estimator
 from fseval.types import AbstractEstimator, Callback, TerminalColor
-from humanfriendly import format_timespan
-from sqlalchemy.engine import Engine
 
 
 @dataclass
@@ -176,7 +176,7 @@ class Experiment(AbstractEstimator):
                 estimator.postfit()
 
     def _aggregate_dataframe_scores(self, a: pd.DataFrame, b: pd.DataFrame):
-        return a.append(b)
+        return pd.concat([a, b])
 
     def _aggregate_dict_scores(self, a: Dict, b: Dict):
         aggregated = {}
