@@ -1,16 +1,16 @@
-from dataclasses import dataclass, field
-from typing import Dict
+from dataclasses import dataclass
 
 from omegaconf import MISSING
 
 from fseval.pipeline.cv import CrossValidator
 from fseval.pipeline.dataset import DatasetLoader
-from fseval.types import AbstractStorage, Callback
+from fseval.pipelines._callback_collection import CallbackCollection
+from fseval.types import AbstractStorage
 
 
 @dataclass
 class Pipeline:
-    callbacks: Dict[str, Callback] = field(default_factory=dict)
+    callbacks: CallbackCollection = MISSING
     dataset: DatasetLoader = MISSING
     cv: CrossValidator = MISSING
     storage: AbstractStorage = MISSING
