@@ -1,10 +1,12 @@
 import logging
 from dataclasses import dataclass
-from typing import Optional
+from typing import Dict, Optional
+
+from omegaconf import MISSING
 
 from fseval.pipeline.estimator import Estimator
 from fseval.pipeline.resample import Resample
-from omegaconf import MISSING
+from fseval.types import AbstractMetric
 
 from .._pipeline import Pipeline
 
@@ -13,7 +15,7 @@ logger = logging.getLogger(__name__)
 
 @dataclass
 class RankAndValidatePipeline(Pipeline):
-    """Instantiated version of `RankAndValidateConfig`: the actual pipeline
+    """Instantiated version of `PipelineConfig`: the actual pipeline
     implementation."""
 
     pipeline: str = MISSING
@@ -23,8 +25,7 @@ class RankAndValidatePipeline(Pipeline):
     n_bootstraps: int = MISSING
     n_jobs: Optional[int] = MISSING
     all_features_to_select: str = MISSING
-    upload_ranking_scores: bool = MISSING
-    upload_validation_scores: bool = MISSING
+    metrics: Dict[str, AbstractMetric] = MISSING
 
     def _get_config(self):
         return {
